/**
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 *
 * 
 * @format
 */
'use strict';

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault")["default"];

var _defineProperty2 = _interopRequireDefault(require("@babel/runtime/helpers/defineProperty"));

var _objectSpread2 = _interopRequireDefault(require("@babel/runtime/helpers/objectSpread2"));

var invariant = require('invariant');

var isLiveStateValue = require('./isLiveStateValue');
/**
 * Wrap the return `value` of the @live resolver that return @weak
 * object into {`key`: `value`} object.
 */


function weakObjectWrapperLive(resolverFn, key, isPlural) {
  return function () {
    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    var liveState = resolverFn.apply(null, args);
    !isLiveStateValue(liveState) ? process.env.NODE_ENV !== "production" ? invariant(false, 'Resolver is expected to return a LiveState value.') : invariant(false) : void 0;
    return (0, _objectSpread2["default"])((0, _objectSpread2["default"])({}, liveState), {}, {
      read: weakObjectWrapper(function () {
        return liveState.read();
      }, key, isPlural)
    });
  };
}
/**
 * Wrap the return `value` of the resolver that return @weak
 * object into {`key`: `value`} object.
 */


function weakObjectWrapper(resolverFn, key, isPlural) {
  return function () {
    for (var _len2 = arguments.length, args = new Array(_len2), _key2 = 0; _key2 < _len2; _key2++) {
      args[_key2] = arguments[_key2];
    }

    var data = resolverFn.apply(null, args);

    if (isPlural) {
      !Array.isArray(data) ? process.env.NODE_ENV !== "production" ? invariant(false, 'Resolver is expected to return a plural value.') : invariant(false) : void 0;
      return data.map(function (item) {
        return (0, _defineProperty2["default"])({}, key, item);
      });
    } else {
      return (0, _defineProperty2["default"])({}, key, data);
    }
  };
}

module.exports = {
  weakObjectWrapperLive: weakObjectWrapperLive,
  weakObjectWrapper: weakObjectWrapper
};